Documentation
¶
Index ¶
- func NewClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredVirtualClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewVirtualClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ClusterVersionInformer
- type Interface
- type VirtualClusterInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterVersionInformer ¶
func NewClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterVersionInformer constructs a new informer for ClusterVersion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterVersionInformer ¶
func NewFilteredClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterVersionInformer constructs a new informer for ClusterVersion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredVirtualClusterInformer ¶
func NewFilteredVirtualClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredVirtualClusterInformer constructs a new informer for VirtualCluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewVirtualClusterInformer ¶
func NewVirtualClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewVirtualClusterInformer constructs a new informer for VirtualCluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterVersionInformer ¶
type ClusterVersionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterVersionLister
}
ClusterVersionInformer provides access to a shared informer and lister for ClusterVersions.
type Interface ¶
type Interface interface {
// ClusterVersions returns a ClusterVersionInformer.
ClusterVersions() ClusterVersionInformer
// VirtualClusters returns a VirtualClusterInformer.
VirtualClusters() VirtualClusterInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type VirtualClusterInformer ¶
type VirtualClusterInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.VirtualClusterLister
}
VirtualClusterInformer provides access to a shared informer and lister for VirtualClusters.